@@ -31,6 +31,9 @@ class Figure:
     @property
     def data(self):
         return self._data
+    def set_data(self, data: Any):
+        self._data = data
+        self._serialized_data = _serialize(data)
     def url(self, *, label: str, project_id: Union[str, None]=None, base_url: Union[str, None]=None, view_url: Union[str, None] = None):
         if base_url is None:
             base_url = default_base_url
