@@ -1,9 +1,9 @@
 import altair as alt
-from figurl.core.Figure import Figure
+from ....core.Figure import Figure
 
 class Altair(Figure):
     def __init__(self, chart: alt.Chart):
         data = {
             'spec': chart.to_dict()
         }
-        super().__init__(view_url='gs://figurl/vegalite-1', data=data)
\ No newline at end of file
+        super().__init__(view_url='gs://figurl/vegalite-2', data=data)
\ No newline at end of file
